@@ -65,7 +65,7 @@ QVector<AbstractResource*> KNSBackendTest::getResources(ResultsStream* stream)
     QSignalSpy spyResources(stream, &ResultsStream::destroyed);
     QVector<AbstractResource*> resources;
     connect(stream, &ResultsStream::resourcesFound, this, [&resources](const QVector<AbstractResource*>& res) { resources += res; });
-    Q_ASSERT(spyResources.wait());
+    Q_ASSERT(spyResources.wait(10000));
     Q_ASSERT(!resources.isEmpty());
     return resources;
 }
@@ -96,8 +96,6 @@ void KNSBackendTest::testRetrieval()
         QVERIFY(res->homepage().isValid() && !res->homepage().isEmpty());
         QVERIFY(res->state() > AbstractResource::Broken);
         QVERIFY(res->addonsInformation().isEmpty());
-        QVERIFY(res->thumbnailUrl().isValid() || res->thumbnailUrl().isEmpty());
-        QVERIFY(res->screenshotUrl().isValid() || res->screenshotUrl().isEmpty());
 
         QSignalSpy spy(res, &AbstractResource::screenshotsFetched);
         res->fetchScreenshots();
@@ -135,6 +133,13 @@ void KNSBackendTest::reviewsArrived(AbstractResource* r, const QVector<ReviewPtr
 
 void KNSBackendTest::testResourceByUrl()
 {
-    const auto res = getResources(m_backend->findResourceByPackageName(QUrl(QStringLiteral("kns://") + m_backend->name() + QStringLiteral("/api.kde-look.org/1136471"))));
+    const QUrl url(QStringLiteral("kns://") + m_backend->name() + QStringLiteral("/api.kde-look.org/1136471"));
+    const QVector<QUrl> res = kTransform<QVector<QUrl>>(getResources(m_backend->findResourceByPackageName(url)), [](AbstractResource* res){ return res->url(); });
     QCOMPARE(res.count(), 1);
+    QCOMPARE(url, res.constFirst());
+
+    AbstractResourcesBackend::Filters f;
+    f.resourceUrl = url;
+    const QVector<QUrl> res2 = kTransform<QVector<QUrl>>(getResources(m_backend->search(f)), [](AbstractResource* res){ return res->url(); });
+    QCOMPARE(res, res2);
 }
