@@ -51,9 +51,9 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         ResultsStream* findResourceByPackageName(const QUrl& search) override;
         int updatesCount() const override;
 
-        void installApplication(AbstractResource* app) override;
-        void installApplication(AbstractResource* app, const AddonList& addons) override;
-        void removeApplication(AbstractResource* app) override;
+        Transaction* installApplication(AbstractResource* app) override;
+        Transaction* installApplication(AbstractResource* app, const AddonList& addons) override;
+        Transaction* removeApplication(AbstractResource* app) override;
         bool isValid() const override { return true; }
         QSet<AbstractResource*> upgradeablePackages() const;
         bool isFetching() const override;
@@ -69,6 +69,9 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
 
         AbstractResource * resourceForFile(const QUrl & ) override;
         void checkForUpdates() override;
+        QString displayName() const override;
+
+        bool hasApplications() const override { return true; }
 
     public Q_SLOTS:
         void reloadPackageList();
@@ -86,6 +89,8 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint);
 
     private:
+        void delayedInit();
+
         template <typename T>
         T resourcesByPackageNames(const QStringList& names) const;
         void fetchUpdates();
