@@ -44,12 +44,16 @@ StandardBackendUpdater::StandardBackendUpdater(AbstractResourcesBackend* parent)
     });
     connect(TransactionModel::global(), &TransactionModel::transactionRemoved, this, &StandardBackendUpdater::transactionRemoved);
     connect(TransactionModel::global(), &TransactionModel::transactionAdded, this, &StandardBackendUpdater::transactionAdded);
+
+    m_timer.setSingleShot(true);
+    m_timer.setInterval(10);
+    connect(&m_timer, &QTimer::timeout, this, &StandardBackendUpdater::refreshUpdateable);
 }
 
-void StandardBackendUpdater::resourcesChanged(AbstractResource* /*res*/, const QVector<QByteArray>& props)
+void StandardBackendUpdater::resourcesChanged(AbstractResource* res, const QVector<QByteArray>& props)
 {
-    if (props.contains("state"))
-        refreshUpdateable();
+    if (props.contains("state") && (res->state() == AbstractResource::Upgradeable || m_upgradeable.contains(res)))
+        m_timer.start();
 }
 
 bool StandardBackendUpdater::hasUpdates() const
@@ -113,7 +117,12 @@ void StandardBackendUpdater::transactionRemoved(Transaction* t)
 
 void StandardBackendUpdater::refreshUpdateable()
 {
-    if (m_backend->isFetching() || !m_backend->isValid() || isProgressing()) {
+    if (m_backend->isFetching() || !m_backend->isValid()) {
+        return;
+    }
+
+    if (isProgressing()) {
+        m_timer.start(1000);
         return;
     }
 
